@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009-2010 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009-2011 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -212,6 +212,65 @@ static const stmt_list_t g_stmts[] = {
 /*                                                                            */
 /******************************************************************************/
 
+static void
+database_vhstmt_free (valhalla_db_stmt_t *vhstmt)
+{
+  if (!vhstmt)
+    return;
+
+  if (vhstmt->sql)
+    free (vhstmt->sql);
+  free (vhstmt);
+}
+
+/*
+ * This function is a replacement of sqlite3_exec() which should not be used
+ * anymore. Only one SQL query must be passed in the argument.
+ */
+static int
+database_sql_exec (sqlite3 *db, const char *sql,
+                   valhalla_db_stmt_t *vhstmt, char **errmsg)
+{
+  int res;
+  sqlite3_stmt *stmt = NULL;
+
+  if (vhstmt)
+    stmt = vhstmt->stmt;
+
+  /* new query ? */
+  if (!stmt)
+  {
+    res = sqlite3_prepare_v2 (db, sql, -1, &stmt, NULL);
+    if (res != SQLITE_OK)
+      goto out;
+  }
+
+  res = sqlite3_step (stmt);
+  if (res == SQLITE_ROW && vhstmt)
+  {
+    unsigned int i;
+
+    vhstmt->stmt = stmt;
+    vhstmt->cnt  = sqlite3_column_count (stmt);
+    for (i = 0; i < vhstmt->cnt && i < VHSTMT_MAXCOLS; i++)
+      vhstmt->cols[i] = (const char *) sqlite3_column_text (stmt, i);
+
+    return 0;
+  }
+
+ out:
+  if (res != SQLITE_DONE && res != SQLITE_OK)
+  {
+    const char *err = sqlite3_errmsg (db);
+    if (err)
+      *errmsg = strdup (err);
+  }
+
+  database_vhstmt_free (vhstmt);
+  sqlite3_finalize (stmt);
+  return 1;
+}
+
 static valhalla_meta_grp_t
 database_group_get (database_t *database, int64_t id)
 {
@@ -293,6 +352,53 @@ database_file_typeid_get (database_t *database, valhalla_file_type_t type)
   return 0;
 }
 
+/*
+ * The query plan is useful in order to found the best way for indexing
+ * the tables.
+ */
+static void
+database_query_plan (database_t *database, const char *sql)
+{
+  int row = 0;
+  size_t size;
+  const char *plan = "EXPLAIN QUERY PLAN ";
+  valhalla_db_stmt_t *vhstmt;
+
+  if (!vh_log_test (VALHALLA_MSG_VERBOSE))
+    return;
+
+  if (!sql)
+    return;
+
+  vhstmt = calloc (1, sizeof (*vhstmt));
+  if (!vhstmt)
+    return;
+
+  size = strlen (sql) + strlen (plan) + 1;
+  vhstmt->sql = malloc (size);
+  if (!vhstmt->sql)
+  {
+    free (vhstmt);
+    return;
+  }
+
+  snprintf (vhstmt->sql, size, "%s%s", plan, sql);
+  while (!database_sql_exec (database->db, vhstmt->sql, vhstmt, NULL))
+  {
+    if (!row)
+    {
+      row = 1;
+      vh_log (VALHALLA_MSG_VERBOSE, "Query plan for : %s", sql);
+    }
+
+    vh_log (VALHALLA_MSG_VERBOSE, "| %s | %s | %s",
+            vhstmt->cols[0], vhstmt->cols[1], vhstmt->cols[2]);
+  }
+
+  if (row)
+    vh_log (VALHALLA_MSG_VERBOSE, "");
+}
+
 static int
 database_prepare_stmt (database_t *database)
 {
@@ -313,6 +419,8 @@ database_prepare_stmt (database_t *database)
       vh_log (VALHALLA_MSG_ERROR, "%s", sqlite3_errmsg (database->db));
       return -1;
     }
+
+    database_query_plan (database, database->stmts[i].sql);
   }
 
   return 0;
@@ -1334,65 +1442,6 @@ vh_database_step_transaction (database_t *database,
   }
 }
 
-static void
-database_vhstmt_free (valhalla_db_stmt_t *vhstmt)
-{
-  if (!vhstmt)
-    return;
-
-  if (vhstmt->sql)
-    free (vhstmt->sql);
-  free (vhstmt);
-}
-
-/*
- * This function is a replacement of sqlite3_exec() which should not be used
- * anymore. Only one SQL query must be passed in the argument.
- */
-static int
-database_sql_exec (sqlite3 *db, const char *sql,
-                   valhalla_db_stmt_t *vhstmt, char **errmsg)
-{
-  int res;
-  sqlite3_stmt *stmt = NULL;
-
-  if (vhstmt)
-    stmt = vhstmt->stmt;
-
-  /* new query ? */
-  if (!stmt)
-  {
-    res = sqlite3_prepare_v2 (db, sql, -1, &stmt, NULL);
-    if (res != SQLITE_OK)
-      goto out;
-  }
-
-  res = sqlite3_step (stmt);
-  if (res == SQLITE_ROW && vhstmt)
-  {
-    unsigned int i;
-
-    vhstmt->stmt = stmt;
-    vhstmt->cnt  = sqlite3_column_count (stmt);
-    for (i = 0; i < vhstmt->cnt && i < VHSTMT_MAXCOLS; i++)
-      vhstmt->cols[i] = (const char *) sqlite3_column_text (stmt, i);
-
-    return 0;
-  }
-
- out:
-  if (res != SQLITE_DONE && res != SQLITE_OK)
-  {
-    const char *err = sqlite3_errmsg (db);
-    if (err)
-      *errmsg = strdup (err);
-  }
-
-  database_vhstmt_free (vhstmt);
-  sqlite3_finalize (stmt);
-  return 1;
-}
-
 #define DB_SQL_EXEC_OR_GOTO(d, s, m, g)       \
   database_sql_exec (d, s, NULL, &m);         \
   if (m)                                      \
@@ -1547,9 +1596,13 @@ vh_database_init (const char *path)
 
   if (sqlite3_threadsafe () != 1)
   {
-    vh_log (VALHALLA_MSG_ERROR,
-            "SQLite3 is not compiled with serialized threading mode!");
-    return NULL;
+    res = sqlite3_config (SQLITE_CONFIG_SERIALIZED);
+    if (res != SQLITE_OK)
+    {
+      vh_log (VALHALLA_MSG_ERROR,
+              "SQLite3 is not compiled with serialized threading mode!");
+      return NULL;
+    }
   }
 
   database = calloc (1, sizeof (database_t));
@@ -1652,19 +1705,20 @@ vh_database_init (const char *path)
   }                                                                  \
   while (0)
 
-#define VH_DB_RETURN_SQL_PREPARE(d, s, v)                     \
-  {                                                           \
-    int rc;                                                   \
-    v->sql = strdup (s);                                      \
-    rc = sqlite3_prepare_v2 (d, v->sql, -1, &v->stmt, NULL);  \
-    if (rc != SQLITE_OK)                                      \
-    {                                                         \
-      vh_log (VALHALLA_MSG_ERROR,                             \
-              "%s - query: %s", sqlite3_errmsg (d), s);       \
-      database_vhstmt_free (v);                               \
-      return NULL;                                            \
-    }                                                         \
-    return v;                                                 \
+#define VH_DB_RETURN_SQL_PREPARE(d, s, v)                         \
+  {                                                               \
+    int rc;                                                       \
+    database_query_plan (d, s);                                   \
+    v->sql = strdup (s);                                          \
+    rc = sqlite3_prepare_v2 (d->db, v->sql, -1, &v->stmt, NULL);  \
+    if (rc != SQLITE_OK)                                          \
+    {                                                             \
+      vh_log (VALHALLA_MSG_ERROR,                                 \
+              "%s - query: %s", sqlite3_errmsg (d->db), s);       \
+      database_vhstmt_free (v);                                   \
+      return NULL;                                                \
+    }                                                             \
+    return v;                                                     \
   }
 
 static inline int
@@ -1941,7 +1995,7 @@ vh_database_metalist_get (database_t *database,
    */
   SQL_CONCAT (sql, SELECT_LIST_METADATA_END);
 
-  VH_DB_RETURN_SQL_PREPARE (database->db, sql, vhstmt)
+  VH_DB_RETURN_SQL_PREPARE (database, sql, vhstmt)
 }
 
 const valhalla_db_fileres_t *
@@ -2024,7 +2078,7 @@ vh_database_filelist_get (database_t *database,
   /* ORDER BY file_id; */
   SQL_CONCAT (sql, SELECT_LIST_FILE_END);
 
-  VH_DB_RETURN_SQL_PREPARE (database->db, sql, vhstmt)
+  VH_DB_RETURN_SQL_PREPARE (database, sql, vhstmt)
 }
 
 const valhalla_db_metares_t *
@@ -2122,7 +2176,7 @@ vh_database_file_get (database_t *database,
   /* ORDER BY assoc.priority__; */
   SQL_CONCAT (sql, SELECT_FILE_END);
 
-  VH_DB_RETURN_SQL_PREPARE (database->db, sql, vhstmt)
+  VH_DB_RETURN_SQL_PREPARE (database, sql, vhstmt)
 }
 
 /******************************************************************************/
