@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -740,12 +740,12 @@ grabber_stats_dump (vh_stats_t *stats, void *data)
                              "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~");
 #if 0
   STATS_DUMP ("GLOBAL", success_all, total_all, total_all);
-#else
+#else /* 0 */
   vh_log (VALHALLA_MSG_INFO,
           "%-12s | %6"PRIu64"/%-6"PRIu64" (%6.2f%%)",
           "GLOBAL", success_all, total_all,
           (total_all) ? 100.0 * (success_all) / (total_all) : 100);
-#endif /* 0 */
+#endif /* !0 */
 }
 
 grabber_t *
@@ -764,11 +764,14 @@ vh_grabber_init (valhalla_t *handle, unsigned int nb)
   if (!grabber)
     return NULL;
 
-  if (nb > ARRAY_NB_ELEMENTS (grabber->thread))
+  grabber->valhalla = handle; /* VH_HANDLE */
+  grabber->nb       = nb ? nb : GRABBER_NUMBER_DEF;
+
+  if (grabber->nb > ARRAY_NB_ELEMENTS (grabber->thread))
     goto err;
 
   pthread_mutex_init (&grabber->mutex_run, NULL);
-  for (i = 0; i < nb; i++)
+  for (i = 0; i < grabber->nb; i++)
   {
     grabber->timer[i] = vh_timer_thread_create ();
     pthread_mutex_init (&grabber->mutex_grabber[i], NULL);
@@ -779,9 +782,6 @@ vh_grabber_init (valhalla_t *handle, unsigned int nb)
   if (!grabber->fifo)
     goto err;
 
-  grabber->valhalla = handle; /* VH_HANDLE */
-  grabber->nb       = nb ? nb : GRABBER_NUMBER_DEF;
-
   grabber->list = grabber_register_childs (handle->url_ctl);
   if (!grabber->list)
     goto err;
