@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -89,7 +89,7 @@ grabber_ffmpeg_properties_get (grabber_ffmpeg_t *ffmpeg,
 
     switch (codec->codec_type)
     {
-    case CODEC_TYPE_AUDIO:
+    case AVMEDIA_TYPE_AUDIO:
       audio_streams++;
       name = grabber_ffmpeg_codec_name (codec->codec_id);
       if (name)
@@ -103,7 +103,7 @@ grabber_ffmpeg_properties_get (grabber_ffmpeg_t *ffmpeg,
                               VALHALLA_METADATA_AUDIO_BITRATE, ffmpeg->pl);
       break;
 
-    case CODEC_TYPE_VIDEO:
+    case AVMEDIA_TYPE_VIDEO:
       /* Common part (image + video) */
       video_streams++;
       name = grabber_ffmpeg_codec_name (codec->codec_id);
@@ -138,7 +138,7 @@ grabber_ffmpeg_properties_get (grabber_ffmpeg_t *ffmpeg,
                             VALHALLA_METADATA_VIDEO_ASPECT, ffmpeg->pl);
       break;
 
-    case CODEC_TYPE_SUBTITLE:
+    case AVMEDIA_TYPE_SUBTITLE:
       sub_streams++;
       break;
 
