@@ -45,8 +45,8 @@
 
 #define TMDB_API_KEY      "5401cd030990fba60e1c23d2832de62e"
 
-#define TMDB_QUERY_SEARCH "http://%s/2.0/Movie.search?title=%s&api_key=%s"
-#define TMDB_QUERY_INFO   "http://%s/2.0/Movie.getInfo?id=%s&api_key=%s"
+#define TMDB_QUERY_SEARCH "http://%s/2.1/Movie.search/en/xml/%s/%s"
+#define TMDB_QUERY_INFO   "http://%s/2.1/Movie.getInfo/en/xml/%s/%s"
 
 typedef struct grabber_tmdb_s {
   url_t *handler;
@@ -89,6 +89,34 @@ grabber_tmdb_get_picture (file_data_t *fdata, const char *keywords,
   free (cover);
 }
 
+static xmlChar *
+grabber_tmdb_parse_forimage (xmlNode *n, const char *type, const char *size)
+{
+  xmlNode *node;
+  xmlChar *content_type = NULL;
+  xmlChar *content_size = NULL;
+  xmlChar *content_url  = NULL;
+
+  node = vh_xml_get_node_tree (n, "images");
+  if (!node || node->type != XML_ELEMENT_NODE)
+    return NULL;
+
+  for (node = node->children; node && !content_url; node = node->next)
+  {
+      content_type = vh_xml_get_attr_value_from_node (node, "type");
+      content_size = vh_xml_get_attr_value_from_node (node, "size");
+
+      if (   !xmlStrcmp (content_type, (const xmlChar *) type)
+          && !xmlStrcmp (content_size, (const xmlChar *) size))
+        content_url = vh_xml_get_attr_value_from_node (node, "url");
+
+      xmlFree (content_type);
+      xmlFree (content_size);
+  }
+
+  return content_url;
+}
+
 static int
 grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
                   const char *keywords, char *escaped_keywords)
@@ -98,7 +126,7 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
 
   xmlDocPtr doc;
   xmlChar *tmp;
-  xmlNode *n, *node;
+  xmlNode *n;
 
   int res_int = 0;
 
@@ -107,7 +135,7 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
 
   /* proceed with TMDB search request */
   snprintf (url, sizeof (url), TMDB_QUERY_SEARCH,
-            TMDB_HOSTNAME, escaped_keywords, TMDB_API_KEY);
+            TMDB_HOSTNAME, TMDB_API_KEY, escaped_keywords);
 
   vh_log (VALHALLA_MSG_VERBOSE, "Search Request: %s", url);
 
@@ -153,7 +181,7 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
 
   /* proceed with TMDB search request */
   snprintf (url, sizeof (url),
-            TMDB_QUERY_INFO, TMDB_HOSTNAME, tmp, TMDB_API_KEY);
+            TMDB_QUERY_INFO, TMDB_HOSTNAME, TMDB_API_KEY, tmp);
   xmlFree (tmp);
 
   vh_log (VALHALLA_MSG_VERBOSE, "Info Request: %s", url);
@@ -173,7 +201,7 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
   n = xmlDocGetRootElement (doc);
 
   /* fetch movie overview description */
-  vh_grabber_parse_str (fdata, n, "short_overview",
+  vh_grabber_parse_str (fdata, n, "overview",
                         VALHALLA_METADATA_SYNOPSIS, VALHALLA_LANG_EN, tmdb->pl);
 
   /* fetch movie runtime (in minutes) */
@@ -181,7 +209,7 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
                         VALHALLA_LANG_UNDEF, tmdb->pl);
 
   /* fetch movie year of production */
-  vh_xml_search_int (n, "release", &res_int);
+  vh_xml_search_int (n, "released", &res_int);
   if (res_int)
   {
     vh_grabber_parse_int (fdata, res_int, VALHALLA_METADATA_YEAR, tmdb->pl);
@@ -205,27 +233,25 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
   vh_grabber_parse_str (fdata, n, "revenue", VALHALLA_METADATA_REVENUE,
                         VALHALLA_LANG_UNDEF, tmdb->pl);
 
-  /* fetch movie country */
-  node = vh_xml_get_node_tree (n, "country");
-  if (node)
-  {
-    tmp = vh_xml_get_prop_value_from_tree (node, "short_name");
-    if (tmp)
-    {
-      vh_metadata_add_auto (&fdata->meta_grabber, VALHALLA_METADATA_COUNTRY,
-                            (char *) tmp, VALHALLA_LANG_EN, tmdb->pl);
-      xmlFree (tmp);
-    }
-  }
+  /* fetch movie country
+   * <country name="..."/>
+   */
+  vh_grabber_parse_countries (fdata, n, VALHALLA_LANG_EN, tmdb->pl);
 
-  /* fetch movie categories */
+  /* fetch movie categories
+   * <category name="..."/>
+   */
   vh_grabber_parse_categories (fdata, n, VALHALLA_LANG_EN, tmdb->pl);
 
-  /* fetch movie people */
+  /* fetch movie people
+   * <person name="..." character="..." job="..."/>
+   */
   vh_grabber_parse_casting (fdata, n, tmdb->pl);
 
-  /* fetch movie poster */
-  tmp = vh_xml_get_prop_value_from_tree_by_attr (n, "poster", "size", "mid");
+  /* Fetch movie poster
+   * <image type="poster" url="..." size="mid"/>
+   */
+  tmp = grabber_tmdb_parse_forimage (n, "poster", "mid");
   if (tmp)
   {
     grabber_tmdb_get_picture (fdata, keywords, tmp,
@@ -233,8 +259,10 @@ grabber_tmdb_get (grabber_tmdb_t *tmdb, file_data_t *fdata,
     xmlFree (tmp);
   }
 
-  /* fetch movie fan art */
-  tmp = vh_xml_get_prop_value_from_tree_by_attr (n, "backdrop", "size", "mid");
+  /* Fetch movie fan art
+   * <image type="backdrop" url="..." size="w1280"/>
+   */
+  tmp = grabber_tmdb_parse_forimage (n, "backdrop", "w1280");
   if (tmp)
   {
     grabber_tmdb_get_picture (fdata, keywords, tmp,
