@@ -39,6 +39,7 @@ static const struct {
   { "director_of_photography",      "director_of_photography"     },
   { "editor",                       "editor"                      },
   { "original_music_composer",      "composer"                    },
+  { "original music composer",      "composer"                    },
   { "producer",                     "producer"                    },
   { NULL,                           NULL                          }
 };
@@ -94,9 +95,10 @@ vh_grabber_parse_str (file_data_t *fdata, xmlNode *nd, const char *tag,
   }
 }
 
-void
-vh_grabber_parse_categories (file_data_t *fdata, xmlNode *node,
-                             valhalla_lang_t lang, const metadata_plist_t *pl)
+static void
+grabber_parse_list (file_data_t *fdata, xmlNode *node,
+                    const char *node_name, const char *meta,
+                    valhalla_lang_t lang, const metadata_plist_t *pl)
 {
   xmlNode *n;
   int i;
@@ -104,25 +106,56 @@ vh_grabber_parse_categories (file_data_t *fdata, xmlNode *node,
   if (!fdata || !node)
     return;
 
-  n = vh_xml_get_node_tree (node, "category");
-  for (i = 0; i < 5; i++)
+  n = vh_xml_get_node_tree (node, node_name);
+  for (i = 0; i < 5; i++, n = n->next)
   {
     xmlChar *tmp = NULL;
 
     if (!n)
       break;
 
-    tmp = vh_xml_get_prop_value_from_tree (n, "name");
-    if (tmp)
+    switch (n->type)
     {
-      vh_metadata_add_auto (&fdata->meta_grabber,
-                            VALHALLA_METADATA_CATEGORY, (char *) tmp, lang, pl);
-      xmlFree (tmp);
+    case XML_TEXT_NODE:
+      tmp = vh_xml_get_prop_value_from_tree (n, "name");
+      break;
+
+    case XML_ELEMENT_NODE:
+      tmp = vh_xml_get_attr_value_from_node (n, "name");
+      break;
+
+    default:
+      break;
     }
-    n = n->next;
+
+    /* we retry with the next because it depends of n->type */
+    if (!tmp)
+    {
+      --i;
+      continue;
+    }
+
+      vh_metadata_add_auto (&fdata->meta_grabber, meta, (char *) tmp, lang, pl);
+      xmlFree (tmp);
   }
 }
 
+void
+vh_grabber_parse_categories (file_data_t *fdata, xmlNode *node,
+                             valhalla_lang_t lang, const metadata_plist_t *pl)
+{
+  grabber_parse_list (fdata, node,
+                      "category", VALHALLA_METADATA_CATEGORY, lang, pl);
+}
+
+void
+vh_grabber_parse_countries (file_data_t *fdata, xmlNode *node,
+                            valhalla_lang_t lang, const metadata_plist_t *pl)
+{
+  grabber_parse_list (fdata, node,
+                      "country", VALHALLA_METADATA_COUNTRY, lang, pl);
+}
+
 static void
 grabber_add_person (file_data_t *fdata,
                     xmlNode *node, const char *cat, const metadata_plist_t *pl)
@@ -134,6 +167,8 @@ grabber_add_person (file_data_t *fdata,
 
   vh_xml_search_str (node, "name", &name);
   vh_xml_search_str (node, "role", &role);
+  if (!role)
+    vh_xml_search_str (node, "character", &role);
 
   if (name)
   {
@@ -173,7 +208,7 @@ vh_grabber_parse_casting (file_data_t *fdata,
       continue;
 
     for (i = 0; grabber_casting_mapping[i].tag; i++)
-      if (!strcmp ((char *) ch, grabber_casting_mapping[i].tag))
+      if (!strcasecmp ((char *) ch, grabber_casting_mapping[i].tag))
       {
         grabber_add_person (fdata, n, grabber_casting_mapping[i].name, pl);
         break;
