@@ -40,6 +40,9 @@ void vh_grabber_parse_str (file_data_t *fdata,
 void vh_grabber_parse_categories (file_data_t *fdata,
                                   xmlNode *node, valhalla_lang_t lang,
                                   const metadata_plist_t *pl);
+void vh_grabber_parse_countries (file_data_t *fdata,
+                                 xmlNode *node, valhalla_lang_t lang,
+                                 const metadata_plist_t *pl);
 void vh_grabber_parse_casting (file_data_t *fdata,
                                xmlNode *node, const metadata_plist_t *pl);
 #endif /* USE_XML */
