@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009-2011 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -78,17 +78,14 @@ vh_list_append (list_t *list, const void *data, size_t len)
     return;
 
   /* Remove the older item to preserve the depth. */
-  if (list->depth)
+  if (list->depth && list->cnt >= list->depth)
   {
-    if (list->cnt >= list->depth)
-    {
-      list_item_t *item_n = list->item->next;
-      list_item_free (list, list->item);
-      list->item = item_n;
-    }
-    else
-      list->cnt++;
+    list_item_t *item_n = list->item->next;
+    list_item_free (list, list->item);
+    list->item = item_n;
   }
+  else
+    list->cnt++;
 
   list->item_last = item;
 
@@ -157,3 +154,20 @@ vh_list_search (const list_t *list, const void *tocmp,
 
   return NULL;
 }
+
+void *
+vh_list_pos (const list_t *list, unsigned int pos)
+{
+  list_item_t *item;
+
+  if (!list)
+    return NULL;
+
+  if (pos >= list->cnt)
+    return NULL;
+
+  for (item = list->item; pos; pos--, item = item->next)
+    ;
+
+  return item->data;
+}
