@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -79,6 +79,7 @@ parser_is_stopped (parser_t *parser)
   return !run;
 }
 
+/* VH_TEST (parser_decrap_pattern) { */
 #define PATTERN_NUMBER "NUM"
 #define PATTERN_SEASON  "SE"
 #define PATTERN_EPISODE "EP"
@@ -151,6 +152,7 @@ parser_decrap_pattern (char *str, const char *bl,
     *ep = 0;
   }
 }
+/* } VH_TEST (parser_decrap_pattern) */
 
 static void
 parser_decrap_blacklist (char **list, char *str, metadata_t **meta)
@@ -282,7 +284,7 @@ parser_metadata_get (parser_t *parser, AVFormatContext *ctx, const char *file)
   unsigned int i;
   metadata_t *meta = NULL;
   const metadata_t *title_tag = NULL;
-  AVMetadataTag *tag = NULL;
+  AVDictionaryEntry *tag = NULL;
   const metadata_plist_t pl = {
     .metadata = NULL,
     .priority = VALHALLA_METADATA_PL_HIGHEST
@@ -291,20 +293,25 @@ parser_metadata_get (parser_t *parser, AVFormatContext *ctx, const char *file)
   if (!ctx)
     return NULL;
 
-  av_metadata_conv (ctx, NULL, ctx->iformat->metadata_conv);
-
-  while ((tag = av_metadata_get (ctx->metadata,
-                                 "", tag, AV_METADATA_IGNORE_SUFFIX)))
+  while ((tag = av_dict_get (ctx->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)))
     vh_metadata_add_auto (&meta, tag->key, tag->value,
                           VALHALLA_LANG_UNDEF, &pl);
 
   for (i = 0; i < ctx->nb_streams; i++)
   {
     AVStream *st = ctx->streams[i];
-    while ((tag = av_metadata_get (st->metadata,
-                                   "", tag, AV_METADATA_IGNORE_SUFFIX)))
-      vh_metadata_add_auto (&meta, tag->key, tag->value,
+    while ((tag = av_dict_get (st->metadata, "", tag, AV_DICT_IGNORE_SUFFIX)))
+    {
+      const char *key = tag->key;
+
+      /* without this check, it is possible to have more than one title */
+      if (vh_metadata_get (meta, VALHALLA_METADATA_TITLE, 0, &title_tag)
+          && !strcasecmp (key, VALHALLA_METADATA_TITLE))
+        key = VALHALLA_METADATA_TITLE_STREAM;
+
+      vh_metadata_add_auto (&meta, key, tag->value,
                             VALHALLA_LANG_UNDEF, &pl);
+    }
   }
 
   if (!meta)
@@ -339,10 +346,9 @@ parser_stream_info (AVFormatContext *ctx)
   for (i = 0; i < ctx->nb_streams; i++)
   {
     AVStream *st = ctx->streams[i];
-
-    if (st->codec->codec_type == CODEC_TYPE_VIDEO)
+    if (st->codec->codec_type == AVMEDIA_TYPE_VIDEO)
       video_st = 1;
-    else if (st->codec->codec_type == CODEC_TYPE_AUDIO)
+    else if (st->codec->codec_type == AVMEDIA_TYPE_AUDIO)
       audio_st = 1;
   }
 
