@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -35,7 +35,7 @@
  */
 #ifdef _WIN32
 #define VH_I64 "lli"
-#else
+#else /* _WIN32 */
 #define VH_I64 PRIi64
 #endif /* !_WIN32 */
 
