@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009-2010 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009-2011 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -505,11 +505,11 @@ valhalla_grabber_next (valhalla_t *handle, const char *id)
 
 #ifdef USE_GRABBER
   return vh_grabber_next (handle->grabber, id);
-#else
+#else /* USE_GRABBER */
   vh_log (VALHALLA_MSG_WARNING,
           "This function is usable only with grabbing support!");
   return NULL;
-#endif /* USE_GRABBER */
+#endif /* !USE_GRABBER */
 }
 
 valhalla_metadata_pl_t
@@ -524,11 +524,11 @@ valhalla_grabber_priority_read (valhalla_t *handle,
 
 #ifdef USE_GRABBER
   return vh_grabber_priority_read (handle->grabber, id, meta);
-#else
+#else /* USE_GRABBER */
   vh_log (VALHALLA_MSG_WARNING,
           "This function is usable only with grabbing support!");
   return 0;
-#endif /* USE_GRABBER */
+#endif /* !USE_GRABBER */
 }
 
 const char *
@@ -641,7 +641,7 @@ valhalla_init (const char *db, valhalla_init_param_t *param)
     cb.gl_data = pp->gl_data;
     cb.md_data = pp->md_data;
 
-    handle->event_handler = vh_event_handler_init (handle, &cb);
+    handle->event_handler = vh_event_handler_init (handle, &cb, pp->od_meta);
     if (!handle->event_handler)
       goto err;
   }
@@ -726,6 +726,17 @@ valhalla_ondemand (valhalla_t *handle, const char *file)
                            ACTION_OD_ENGAGE, odfile);
 }
 
+const char *
+valhalla_ondemand_cb_meta (valhalla_t *handle, const char *meta)
+{
+  vh_log (VALHALLA_MSG_VERBOSE, __FUNCTION__);
+
+  if (!handle)
+    return NULL;
+
+  return vh_event_handler_od_cb_meta (handle->event_handler, meta);
+}
+
 /******************************************************************************/
 /*                                                                            */
 /*                         Public Database Selections                         */
