@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009-2010 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009-2011 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -40,7 +40,7 @@ extern "C" {
 #define VH_VERSION(a, b, c) VH_VERSION_DOT(a, b, c)
 
 #define LIBVALHALLA_VERSION_MAJOR  2
-#define LIBVALHALLA_VERSION_MINOR  0
+#define LIBVALHALLA_VERSION_MINOR  1
 #define LIBVALHALLA_VERSION_MICRO  0
 
 #define LIBVALHALLA_DB_VERSION     2
@@ -246,6 +246,7 @@ typedef enum valhalla_meta_grp {
 #define VALHALLA_METADATA_TITLE                      "title"
 #define VALHALLA_METADATA_TITLE_ALTERNATIVE          "title_alternative"
 #define VALHALLA_METADATA_TITLE_SHOW                 "title_show"
+#define VALHALLA_METADATA_TITLE_STREAM               "title_stream"
 
 /**
  * @}
@@ -521,6 +522,11 @@ typedef struct valhalla_init_param_s {
    * disabled.
    */
   unsigned int decrapifier : 1;
+  /**
+   * If the attribute is set, then the meta keys can be retrieved from the
+   * ondemand callback by using the function valhalla_ondemand_cb_meta().
+   */
+  unsigned int od_meta     : 1;
 
   /**
    * When \p od_cb is defined, an event is sent for each step with an on demand
@@ -783,6 +789,21 @@ void valhalla_scanner_wakeup (valhalla_t *handle);
  */
 void valhalla_ondemand (valhalla_t *handle, const char *file);
 
+/**
+ * \brief Retrieve the meta key when running in the ondemand callback.
+ *
+ * This function is a no-op when it is used elsewhere that an ondemand callback
+ * or if the od_meta attribute of ::valhalla_init_param_t is 0.
+ *
+ * The function returns the key after \p meta, or the first key if \p meta
+ * is NULL. The returned pointer is valid as long as your are in the callback.
+ *
+ * \param[in] handle      Handle on the scanner.
+ * \param[in] meta        Meta or NULL to retrieve the first.
+ * \return the meta or NULL if \p meta is the last (or on error).
+ */
+const char *valhalla_ondemand_cb_meta (valhalla_t *handle, const char *meta);
+
 /**
  * @}
  */
@@ -1106,7 +1127,6 @@ valhalla_db_file_read (valhalla_t *handle, valhalla_db_stmt_t *vhstmt);
  * insertion is canceled and no error is returned, else the 'external' flag is
  * set to 1.
  * \see ::valhalla_db_metares_t
- * \see ::valhalla_db_filemeta_t
  *
  * Please, refer to \ref ext_metadata.
  *
