@@ -1,6 +1,6 @@
 /*
  * GeeXboX Valhalla: tiny media scanner API.
- * Copyright (C) 2009 Mathieu Schroeter <mathieu.schroeter@gamesover.ch>
+ * Copyright (C) 2009-2012 Mathieu Schroeter <mathieu@schroetersa.ch>
  *
  * This file is part of libvalhalla.
  *
@@ -89,7 +89,11 @@ vh_xml_get_prop_value_from_tree_by_attr (xmlNode *root, const char *prop,
     if (!attr || !attr->children)
       continue;
 
-    if (xmlStrcmp ((unsigned char *) attr_name, attr->name))
+    for (; attr; attr = attr->next)
+      if (!xmlStrcmp ((unsigned char *) attr_name, attr->name))
+        break;
+
+    if (!attr)
       continue;
 
     content = xmlNodeGetContent (attr->children);
@@ -113,30 +117,13 @@ xmlChar *
 vh_xml_get_attr_value_from_tree (xmlNode *root,
                                  const char *prop, const char *attr_name)
 {
-  xmlNode *n, *node;
-  xmlAttr *attr;
+  xmlNode *node;
 
   node = vh_xml_get_node_tree (root, prop);
   if (!node)
     return NULL;
 
-  for (n = node; n; n = n->next)
-  {
-    xmlChar *content;
-
-    attr = n->properties;
-    if (!attr || !attr->children)
-      continue;
-
-    if (xmlStrcmp ((unsigned char *) attr_name, attr->name))
-      continue;
-
-    content = xmlNodeGetContent (attr->children);
-    if (content)
-      return content;
-  }
-
-  return NULL;
+  return vh_xml_get_attr_value_from_node (node, attr_name);
 }
 
 xmlChar *
@@ -156,12 +143,14 @@ vh_xml_get_attr_value_from_node (xmlNode *node, const char *attr_name)
     if (!attr || !attr->children)
       continue;
 
-    if (xmlStrcmp ((unsigned char *) attr_name, attr->name))
-      continue;
-
-    content = xmlNodeGetContent (attr->children);
-    if (content)
-      return content;
+    for (; attr; attr = attr->next)
+      if (!xmlStrcmp ((unsigned char *) attr_name, attr->name))
+      {
+        content = xmlNodeGetContent (attr->children);
+        if (content)
+          return content;
+        break;
+      }
   }
 
   return NULL;
@@ -196,12 +185,25 @@ vh_xml_get_xnodes_from_tree (xmlDocPtr doc, xmlChar *xpath)
 int
 vh_xml_search_str (xmlNode *n, const char *node, char **str)
 {
-  xmlChar *tmp;
+  xmlChar *tmp = NULL;
 
   if (*str)
     return 1;
 
-  tmp = vh_xml_get_prop_value_from_tree (n, node);
+  switch (n->type)
+  {
+  case XML_TEXT_NODE:
+    tmp = vh_xml_get_prop_value_from_tree (n, node);
+    break;
+
+  case XML_ELEMENT_NODE:
+    tmp = vh_xml_get_attr_value_from_node (n, node);
+    break;
+
+  default:
+    break;
+  }
+
   if (!tmp)
     return 1;
 
